import * as i0 from '@angular/core';
import { inject, Component, Input, EventEmitter, Output, HostBinding, ViewChild, NgModule } from '@angular/core';
import * as i2 from '@angular/forms';
import { FormGroupDirective, Validators, ReactiveFormsModule, FormsModule, FormBuilder } from '@angular/forms';
import { FormError, FormReadyWrapper } from 'neercms/form/types';
import * as i1$2 from 'neercms/services';
import { CopyPasteService } from 'neercms/services';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { randomSadEmoji } from 'neercms/shared/utilities';
import flatpickr from 'flatpickr';
import { DateTime } from 'luxon';
import { DateRangePicker } from 'vanillajs-datepicker';
import * as i1$1 from '@angular/router';
import { RouterLinkWithHref, Router } from '@angular/router';
import * as i3 from 'ngx-mask';
import { NgxMaskModule } from 'ngx-mask';
import * as i2$1 from 'neercms/core';
import { CoreComponentsModule } from 'neercms/core';
import { ModalsService, ToasterService } from 'neercms/services/viewport';

const errorMessages = {
    required: 'err_required',
    invalidEmail: 'err_invalid_email',
    invalidPassword: 'err_invalid_password',
};

class FieldBaseComponent {
    constructor() {
        this.controlUnlink = false;
        this.required = false;
        this.disabled = false;
        this.errors = errorMessages;
        this.changed = false;
        this.focused = false;
        this.copyPaste = inject(CopyPasteService);
        this.formGroup = inject(FormGroupDirective);
    }
    ngOnInit() {
        var _a;
        // this.formGroup.form.error
        if (this.isTrue(this.controlUnlink)) {
            return;
        }
        if (!this.controlName) {
            throw new FormError("A correct form control mast be linked to the field using 'controlName' property" +
                "If you want to left it unlinked, the 'controlUnlink' mast be explicitly set true");
        }
        (_a = this.formControl) !== null && _a !== void 0 ? _a : (this.formControl = this.formGroup.form.get(this.controlName));
        if (!this.formControl) {
            throw new FormError(`Form control for '${this.controlName}' not exists in FormGroup`);
        }
        setTimeout(() => {
            if (this.required === true || this.required === 'true') {
                this.formControl.addValidators(Validators.required);
            }
            if (this.isTrue(this.disabled)) {
                this.formControl.disable({ onlySelf: true });
            }
            else {
                this.formControl.enable({ onlySelf: true });
            }
        }, 1);
        this.afterInit();
    }
    ngOnChanges(changes) {
        if (changes.disabled && this.formControl) {
            if (this.isTrue(this.disabled)) {
                this.formControl.disable();
            }
            else {
                this.formControl.enable();
            }
        }
    }
    onChange(event) {
        this.changed = true;
    }
    afterInit() { }
    isTrue(bool) {
        return bool === true || bool === 'true';
    }
}
FieldBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FieldBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: FieldBaseComponent, selector: "field-base", inputs: { label: "label", controlName: "controlName", controlUnlink: "controlUnlink", required: "required", disabled: "disabled" }, usesOnChanges: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'field-base',
                    template: ``,
                }]
        }], propDecorators: { label: [{
                type: Input
            }], controlName: [{
                type: Input
            }], controlUnlink: [{
                type: Input
            }], required: [{
                type: Input
            }], disabled: [{
                type: Input
            }] } });

class ActionFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.icon = 'la-paperclip';
        this.action = new EventEmitter();
    }
    ngOnInit() {
        this.disabled = true;
        super.ngOnInit();
    }
    ngOnChanges(changes) {
        if (changes.disabled) {
            this.disabled = true;
            this.formControl.disable();
        }
        else {
            super.onChange();
        }
    }
}
ActionFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: ActionFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
ActionFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: ActionFieldComponent, selector: "nc-action-field", inputs: { icon: "icon" }, outputs: { action: "action" }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input [formControl]=\"formControl\"\n           type=\"text\"\n           class=\"form-control right-padding link-input\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"action.emit()\">\n      <i class=\"las {{icon}}\"></i>\n    </button>\n  </div>\n</div>\n", styles: ["", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: ActionFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-action-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input [formControl]=\"formControl\"\n           type=\"text\"\n           class=\"form-control right-padding link-input\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"action.emit()\">\n      <i class=\"las {{icon}}\"></i>\n    </button>\n  </div>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }], propDecorators: { icon: [{
                type: Input
            }], action: [{
                type: Output
            }] } });

class FieldMessageComponent {
    constructor(currentElementRef) {
        this.currentElementRef = currentElementRef;
        this.show = false;
        this.warn = false;
        this.error = false;
        this.size = 'large';
    }
    ngAfterViewInit() {
        this.currentElementRef.nativeElement.classList.add(this.size);
    }
}
FieldMessageComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldMessageComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
FieldMessageComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: FieldMessageComponent, selector: "nc-field-message", inputs: { show: "show", warn: "warn", error: "error", text: "text", size: "size" }, host: { attributes: { "data-popper-placement": "right" }, properties: { "class.show": "this.show", "class.warn": "this.warn", "class.danger": "this.error" }, classAttribute: "tooltip bs-tooltip-auto fade" }, ngImport: i0, template: `
    <div class="tooltip-arrow"></div>
    <div class="tooltip-inner">{{ text }}</div>
  `, isInline: true, styles: [":host{display:block;position:absolute;top:-.1rem;left:98.5%;z-index:-1;color:var(--tooltip-color)}:host.small{width:auto;min-width:4rem}:host.medium{width:auto;min-width:10rem}:host.show{z-index:10}:host:before{content:\"\";display:block}:host .tooltip-arrow{position:absolute;top:-.15rem;left:-1px;transform:translateY(.95rem)}:host .tooltip-arrow:before{border-width:.5rem;border-right-color:var(--tooltip-bg)}:host .tooltip-inner{padding:.2rem .5rem;background-color:var(--tooltip-bg);border-right:.33rem solid var(--success)}:host.warn .tooltip-inner{border-color:var(--warning)}:host.danger .tooltip-inner{border-color:var(--danger)}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldMessageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-field-message', template: `
    <div class="tooltip-arrow"></div>
    <div class="tooltip-inner">{{ text }}</div>
  `, host: {
                        class: 'tooltip bs-tooltip-auto fade',
                        'data-popper-placement': 'right',
                    }, styles: [":host{display:block;position:absolute;top:-.1rem;left:98.5%;z-index:-1;color:var(--tooltip-color)}:host.small{width:auto;min-width:4rem}:host.medium{width:auto;min-width:10rem}:host.show{z-index:10}:host:before{content:\"\";display:block}:host .tooltip-arrow{position:absolute;top:-.15rem;left:-1px;transform:translateY(.95rem)}:host .tooltip-arrow:before{border-width:.5rem;border-right-color:var(--tooltip-bg)}:host .tooltip-inner{padding:.2rem .5rem;background-color:var(--tooltip-bg);border-right:.33rem solid var(--success)}:host.warn .tooltip-inner{border-color:var(--warning)}:host.danger .tooltip-inner{border-color:var(--danger)}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { show: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.show']
            }], warn: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.warn']
            }], error: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.danger']
            }], text: [{
                type: Input
            }], size: [{
                type: Input
            }] } });

class CheckboxFieldComponent extends FieldBaseComponent {
    afterInit() { }
}
CheckboxFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: CheckboxFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
CheckboxFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: CheckboxFieldComponent, selector: "nc-checkbox-field", usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 checkbox-container\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           type=\"checkbox\"\n           class=\"form-check-input\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n  </div>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                    [show]=\"formControl.hasError('api-error')\"\n                    [error]=\"true\"></nc-field-message>\n</div>\n", styles: ["input{border-width:1.5px!important}.checkbox-container{display:flex;align-items:center;padding-bottom:.25rem}\n", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: FieldMessageComponent, selector: "nc-field-message", inputs: ["show", "warn", "error", "text", "size"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: CheckboxFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-checkbox-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 checkbox-container\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           type=\"checkbox\"\n           class=\"form-check-input\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n  </div>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                    [show]=\"formControl.hasError('api-error')\"\n                    [error]=\"true\"></nc-field-message>\n</div>\n", styles: ["input{border-width:1.5px!important}.checkbox-container{display:flex;align-items:center;padding-bottom:.25rem}\n", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }] });

class NotFoundComponent {
    constructor() {
        this.sadEmoji = randomSadEmoji();
    }
}
NotFoundComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NotFoundComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NotFoundComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: NotFoundComponent, selector: "nc-not-found", ngImport: i0, template: "<div class=\"error\">\n  <h3><span class=\"error-emoji\">{{sadEmoji}}</span> Not Found</h3>\n</div>", styles: [".error{padding-left:1.5rem;font-weight:700;color:var(--danger)}.error-emoji{display:inline-block;margin-right:1rem}h3{font-size:2rem}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NotFoundComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-not-found', template: "<div class=\"error\">\n  <h3><span class=\"error-emoji\">{{sadEmoji}}</span> Not Found</h3>\n</div>", styles: [".error{padding-left:1.5rem;font-weight:700;color:var(--danger)}.error-emoji{display:inline-block;margin-right:1rem}h3{font-size:2rem}\n"] }]
        }], ctorParameters: function () { return []; } });

class FieldsetComponent {
    constructor() {
        this.size = 'small';
        this.row = false;
    }
}
FieldsetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldsetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FieldsetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: FieldsetComponent, selector: "nc-fieldset", inputs: { size: "size", row: "row" }, host: { properties: { "attr.size": "this.size", "class.fields-row": "this.row" } }, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, styles: [":host{display:block}:host[size=small]{max-width:520px}:host[size=medium]{max-width:640px}:host[size=large]{max-width:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FieldsetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-fieldset', template: '<ng-content></ng-content>', styles: [":host{display:block}:host[size=small]{max-width:520px}:host[size=medium]{max-width:640px}:host[size=large]{max-width:100%}\n"] }]
        }], propDecorators: { size: [{
                type: HostBinding,
                args: ['attr.size']
            }, {
                type: Input
            }], row: [{
                type: HostBinding,
                args: ['class.fields-row']
            }, {
                type: Input
            }] } });

const minDate = new Date('1900-01-01');
const maxDate = new Date('2036-01-01');
class DatePickerComponent {
    constructor(currentElement) {
        this.currentElement = currentElement;
        this.datePickerMode = 'date';
    }
    ngAfterViewInit() {
        var _a, _b;
        const dateFrom = this.date.value;
        const dateTo = (_a = this.dateTo) === null || _a === void 0 ? void 0 : _a.value;
        this.picker = flatpickr(this.currentElement.nativeElement, {
            mode: this.pickerMode,
            // inline: true,
            enableTime: this.enableTime,
            time_24hr: true,
            dateFormat: (this.enableDate ? 'd/m/Y ' : '') + (this.enableTime ? 'H:i' : ''),
            monthSelectorType: 'static',
            minDate: minDate,
            maxDate: maxDate,
            defaultDate: dateFrom && dateTo
                ? [DateTime.fromISO(dateFrom).toJSDate(), DateTime.fromISO(dateTo).toJSDate()]
                : dateFrom
                    ? DateTime.fromISO(dateFrom).toJSDate()
                    : undefined,
            locale: {
                // Start from Monday
                firstDayOfWeek: 1,
            },
            onMonthChange: this.onDateChange.bind(this),
            onChange: this.onDateChange.bind(this),
        });
        this.date.registerOnChange(this.formDate.bind(this));
        (_b = this.dateTo) === null || _b === void 0 ? void 0 : _b.registerOnChange(this.formDateTo.bind(this));
    }
    onDateChange(event) {
        if (event.length === 0) {
            this.setDate(null);
            this.setDateTo(null);
        }
        if (event.length === 2) {
            this.setDateTo(DateTime.fromJSDate(event[1]));
        }
        this.setDate(DateTime.fromJSDate(event[0]));
    }
    get pickerMode() {
        if (this.datePickerMode === 'time') {
            this.enableTime = true;
            this.enableDate = false;
            return 'time';
        }
        else if (this.datePickerMode === 'date-range') {
            this.enableTime = false;
            this.enableDate = true;
            return 'range';
        }
        else {
            this.enableTime = this.datePickerMode === 'date-time';
            this.enableDate = true;
            return 'single';
        }
    }
    setDate(value) {
        this.internalDate = value;
        this.date.setValue(value);
    }
    setDateTo(value) {
        var _a;
        this.internalDateTo = value;
        (_a = this.dateTo) === null || _a === void 0 ? void 0 : _a.setValue(value);
    }
    formDate(value) {
        if (this.internalDate !== value) {
            if (!value) {
                this.picker.clear();
            }
            else if (this.internalDate) {
                this.picker.setDate([value.toJSDate(), this.internalDate.toJSDate()]);
            }
            else {
                this.picker.setDate(value.toJSDate());
            }
        }
    }
    formDateTo(value) {
        if (this.internalDateTo !== value) {
            if (!value) {
                this.picker.clear();
            }
            else if (this.internalDateTo) {
                this.picker.setDate([value.toJSDate(), this.internalDateTo.toJSDate()]);
            }
            else {
                this.picker.setDate(value.toJSDate());
            }
        }
    }
}
DatePickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DatePickerComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
DatePickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: DatePickerComponent, selector: "input[ncDatePicker]", inputs: { date: "date", dateTo: "dateTo", datePickerMode: "datePickerMode" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DatePickerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'input[ncDatePicker]',
                    template: ``,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { date: [{
                type: Input
            }], dateTo: [{
                type: Input
            }], datePickerMode: [{
                type: Input
            }] } });

class DateFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.format = 'date';
    }
    afterInit() {
        if (this.controlEndName) {
            this.formControlEnd = this.formGroup.form.get(this.controlEndName);
        }
    }
}
DateFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DateFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
DateFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: DateFieldComponent, selector: "nc-date-field", inputs: { format: "format", controlEndName: "controlEndName" }, usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\"> *\n    </sup>\n  </label>\n  <div class=\"col-sm-8\"\n       [class.focused]=\"focused\">\n    <input ncDatePicker\n           [id]=\"controlName\"\n           type=\"text\"\n           class=\"form-control\"\n           [date]=\"formControl\"\n           [dateTo]=\"formControlEnd\"\n           [datePickerMode]=\"format\"\n           [disabled]=\"disabled\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n  </div>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "input[type=date]::-webkit-inner-spin-button,input[type=date]::-webkit-calendar-picker-indicator{display:none;-webkit-appearance:none}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: DatePickerComponent, selector: "input[ncDatePicker]", inputs: ["date", "dateTo", "datePickerMode"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DateFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-date-field', template: "<div class=\"row mb-3 form-grp\">\n  <label [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\"> *\n    </sup>\n  </label>\n  <div class=\"col-sm-8\"\n       [class.focused]=\"focused\">\n    <input ncDatePicker\n           [id]=\"controlName\"\n           type=\"text\"\n           class=\"form-control\"\n           [date]=\"formControl\"\n           [dateTo]=\"formControlEnd\"\n           [datePickerMode]=\"format\"\n           [disabled]=\"disabled\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n  </div>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "input[type=date]::-webkit-inner-spin-button,input[type=date]::-webkit-calendar-picker-indicator{display:none;-webkit-appearance:none}\n"] }]
        }], propDecorators: { format: [{
                type: Input
            }], controlEndName: [{
                type: Input
            }] } });

class DateRangePickerComponent {
    constructor(currentElement) {
        this.currentElement = currentElement;
        this.dateChange = new EventEmitter();
    }
    ngAfterViewInit() {
        this.datepicker = new DateRangePicker(this.currentElement.nativeElement, {
            allowOneSidedRange: true,
        });
        // this.datepicker.element.addEventListener('changeDate', (e: any) => {
        //   this.date = (e.detail.date as Date).toISOString().split('T')[0];
        //   this.dateChange.emit(this.date);
        // });
    }
}
DateRangePickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DateRangePickerComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
DateRangePickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: DateRangePickerComponent, selector: "nc-date-range-picker", inputs: { date: "date" }, outputs: { dateChange: "dateChange" }, viewQueries: [{ propertyName: "fromDate", first: true, predicate: ["fromDate"], descendants: true }, { propertyName: "toDate", first: true, predicate: ["fromDate"], descendants: true }], ngImport: i0, template: `
    <input />
    <input />
  `, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: DateRangePickerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'nc-date-range-picker',
                    template: `
    <input />
    <input />
  `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { fromDate: [{
                type: ViewChild,
                args: ['fromDate']
            }], toDate: [{
                type: ViewChild,
                args: ['fromDate']
            }], date: [{
                type: Input
            }], dateChange: [{
                type: Output
            }] } });

class FormComponent {
    constructor() {
        this.disableBrowserSecurity = false;
    }
}
FormComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FormComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: FormComponent, selector: "form[ncForm]", inputs: { ready: "ready", disableBrowserSecurity: "disableBrowserSecurity" }, host: { properties: { "class.disable-browser-security": "this.disableBrowserSecurity" }, classAttribute: "form" }, ngImport: i0, template: "<ng-container *ngIf=\"ready.state === 'ready' || ready.state === 'loading'\">\n  <ng-content></ng-content>\n</ng-container>\n<nc-not-found *ngIf=\"ready.state === '404'\"></nc-not-found>\n", styles: [":host{width:100%}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: NotFoundComponent, selector: "nc-not-found" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'form[ncForm]', host: {
                        class: 'form',
                    }, template: "<ng-container *ngIf=\"ready.state === 'ready' || ready.state === 'loading'\">\n  <ng-content></ng-content>\n</ng-container>\n<nc-not-found *ngIf=\"ready.state === '404'\"></nc-not-found>\n", styles: [":host{width:100%}\n"] }]
        }], propDecorators: { ready: [{
                type: Input
            }], disableBrowserSecurity: [{
                type: HostBinding,
                args: ['class.disable-browser-security']
            }, {
                type: Input
            }] } });

class FormContentComponent {
}
FormContentComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormContentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FormContentComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: FormContentComponent, selector: "nc-form-content", ngImport: i0, template: "<ng-content></ng-content>", styles: [":host{display:flex;gap:1.5rem;margin:1rem 0 1rem 1.5rem;justify-content:flex-end;align-items:center;color:var(--text-dim)}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormContentComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-form-content', template: "<ng-content></ng-content>", styles: [":host{display:flex;gap:1.5rem;margin:1rem 0 1rem 1.5rem;justify-content:flex-end;align-items:center;color:var(--text-dim)}\n"] }]
        }] });

class LinkFieldComponent extends FieldBaseComponent {
    constructor(router) {
        super();
        this.router = router;
        this.target = '_blank';
        this.external = false;
    }
    afterInit() {
        var _a;
        this.disabled = true;
        if (!this.linkControlName) {
            throw new FormError("A correct form control mast be linked to the field using 'controlName' property");
        }
        (_a = this.linkControl) !== null && _a !== void 0 ? _a : (this.linkControl = this.formGroup.form.get(this.linkControlName));
        if (!this.linkControl) {
            throw new FormError(`Form control for '${this.linkControlName}' not exists in FormGroup`);
        }
    }
    onRedirect() {
        const dest = this.linkControl.value;
        if (typeof dest !== 'string') {
            throw new FormError('Link url mast be a non-empty string');
        }
        if (this.external) {
            window.open(dest, this.target);
        }
        else {
            this.router.navigate([dest]).catch(() => {
                console.error(`If '${dest}' is an external url, you must to explicitly specify 'external=true' on link field.`);
            });
        }
    }
}
LinkFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: LinkFieldComponent, deps: [{ token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Component });
LinkFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: LinkFieldComponent, selector: "nc-link-field", inputs: { linkControlName: "linkControlName", target: "target", external: "external" }, usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input [formControl]=\"formControl\"\n           type=\"text\"\n           class=\"form-control right-padding link-input\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"onRedirect()\">\n      <i class=\"las la-paperclip\"></i>\n    </button>\n  </div>\n</div>\n", styles: ["", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: LinkFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-link-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input [formControl]=\"formControl\"\n           type=\"text\"\n           class=\"form-control right-padding link-input\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"onRedirect()\">\n      <i class=\"las la-paperclip\"></i>\n    </button>\n  </div>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$1.Router }]; }, propDecorators: { linkControlName: [{
                type: Input
            }], target: [{
                type: Input
            }], external: [{
                type: Input
            }] } });

class NumberFieldComponent extends FieldBaseComponent {
    constructor(numberInputProcessor) {
        super();
        this.numberInputProcessor = numberInputProcessor;
        this.format = 'integer';
        this.minValue = -Infinity;
        this.maxValue = Infinity;
        this.allowCopy = false;
    }
    afterInit() {
        this.mask = this.numberInputProcessor.patternToMask(this.format);
    }
    onChange(event) {
        super.onChange(event);
        if (!this.formControl) {
            return;
        }
        const value = +this.formControl.value;
        if (value < this.minValue) {
            this.formControl.setValue(this.minValue);
        }
        else if (value > this.maxValue) {
            this.formControl.setValue(this.maxValue);
        }
    }
    onKeyUp(event) {
        if (!this.formControl) {
            return;
        }
        // To avoid a float numbers math hell
        function fuckJS(n, inc) {
            const [integer, floating] = n.toString().split('.');
            return parseFloat(+integer + inc + '.' + floating);
        }
        if (event.key === 'ArrowUp') {
            this.formControl.setValue(fuckJS(this.formControl.value, 1));
            this.onChange();
        }
        else if (event.key === 'ArrowDown') {
            this.formControl.setValue(fuckJS(this.formControl.value, -1));
            this.onChange();
        }
    }
}
NumberFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NumberFieldComponent, deps: [{ token: i1$2.NumberInputProcessorService }], target: i0.ɵɵFactoryTarget.Component });
NumberFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: NumberFieldComponent, selector: "nc-number-field", inputs: { format: "format", minValue: "minValue", maxValue: "maxValue", allowCopy: "allowCopy" }, usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\" [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\">*</sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           class=\"form-control\"\n           [class.right-padding]=\"isTrue(allowCopy)\"\n           [mask]=\"mask\"\n           [allowNegativeNumbers]=\"minValue < 0 || maxValue < 0\"\n           (input)=\"onChange($event)\"\n           (keyup)=\"onKeyUp($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button *ngIf=\"isTrue(allowCopy)\" class=\"input-mark\" (click)=\"copyPaste.copyToClipboard(input.value)\">\n      <i class=\"las la-copy\"></i>\n    </button>\n  </div>\n\n  <nc-field-message\n    [text]=\"errors.required\"\n    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n    [error]=\"true\">\n  </nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type=number]{-moz-appearance:textfield}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.MaskDirective, selector: "input[mask], textarea[mask]", inputs: ["mask", "specialCharacters", "patterns", "prefix", "suffix", "thousandSeparator", "decimalMarker", "dropSpecialCharacters", "hiddenInput", "showMaskTyped", "placeHolderCharacter", "shownMaskExpression", "showTemplate", "clearIfNotMatch", "validation", "separatorLimit", "allowNegativeNumbers", "leadZeroDateTime", "triggerOnMaskChange"], outputs: ["maskFilled"], exportAs: ["mask", "ngxMask"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: FieldMessageComponent, selector: "nc-field-message", inputs: ["show", "warn", "error", "text", "size"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NumberFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-number-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\" [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\">*</sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           class=\"form-control\"\n           [class.right-padding]=\"isTrue(allowCopy)\"\n           [mask]=\"mask\"\n           [allowNegativeNumbers]=\"minValue < 0 || maxValue < 0\"\n           (input)=\"onChange($event)\"\n           (keyup)=\"onKeyUp($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button *ngIf=\"isTrue(allowCopy)\" class=\"input-mark\" (click)=\"copyPaste.copyToClipboard(input.value)\">\n      <i class=\"las la-copy\"></i>\n    </button>\n  </div>\n\n  <nc-field-message\n    [text]=\"errors.required\"\n    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n    [error]=\"true\">\n  </nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type=number]{-moz-appearance:textfield}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.NumberInputProcessorService }]; }, propDecorators: { format: [{
                type: Input
            }], minValue: [{
                type: Input
            }], maxValue: [{
                type: Input
            }], allowCopy: [{
                type: Input
            }] } });

class PasswordFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.showText = false;
    }
    afterInit() { }
}
PasswordFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: PasswordFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PasswordFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: PasswordFieldComponent, selector: "nc-password-field", usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\" [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\">*</sup>\n  </label>\n  <div class=\"col-sm-8 input-wrapper\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           [type]=\"showText ? 'text' : 'password'\"\n           class=\"form-control right-padding\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"showText = !showText\">\n      <i class=\"las\"\n         [class.la-eye]=\"showText\"\n         [class.la-eye-slash]=\"!showText\"></i>\n    </button>\n  </div>\n\n  <nc-field-message [text]=\"errors.required\"\n                    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n                    [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                    [show]=\"formControl.hasError('api-error')\"\n                    [error]=\"true\"></nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: FieldMessageComponent, selector: "nc-field-message", inputs: ["show", "warn", "error", "text", "size"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: PasswordFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-password-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\" [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\">*</sup>\n  </label>\n  <div class=\"col-sm-8 input-wrapper\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           [type]=\"showText ? 'text' : 'password'\"\n           class=\"form-control right-padding\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\"/>\n    <button class=\"input-mark\" (click)=\"showText = !showText\">\n      <i class=\"las\"\n         [class.la-eye]=\"showText\"\n         [class.la-eye-slash]=\"!showText\"></i>\n    </button>\n  </div>\n\n  <nc-field-message [text]=\"errors.required\"\n                    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n                    [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                    [show]=\"formControl.hasError('api-error')\"\n                    [error]=\"true\"></nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }] });

class SelectFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.options = [];
        this.selectedChange = new EventEmitter();
    }
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes.options) {
            if (!this.isTrue(this.required)) {
                this.options.unshift();
            }
            this.getOptionByFormValue();
        }
    }
    afterInit() {
        var _a;
        if (!this.options) {
            this.selected = {
                key: null,
                title: 'No Options Provided',
            };
        }
        else {
            this.getOptionByFormValue();
        }
        (_a = this.formControl) === null || _a === void 0 ? void 0 : _a.valueChanges.subscribe(v => {
            this.getOptionByFormValue();
        });
    }
    onOptionSelect(option) {
        var _a, _b;
        this.selected = option;
        this.selectedChange.emit(option);
        (_a = this.formControl) === null || _a === void 0 ? void 0 : _a.setValue(option.key);
        (_b = option.onSelected) === null || _b === void 0 ? void 0 : _b.call(option, option);
    }
    getOptionByFormValue() {
        var _a, _b, _c;
        const formValue = (_b = (_a = this.formControl) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.toString().toLowerCase();
        if (formValue && (!this.selected || this.selected.key !== formValue)) {
            this.selected =
                (_c = this.options.find(x => { var _a; return ((_a = x.key) === null || _a === void 0 ? void 0 : _a.toString().toLowerCase()) === formValue; })) !== null && _c !== void 0 ? _c : SelectFieldComponent.notSelectedOption;
        }
        else if (!this.selected) {
            this.selected = this.options[0];
        }
    }
}
SelectFieldComponent.notSelectedOption = {
    key: null,
    title: 'Not Selected',
};
SelectFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SelectFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
SelectFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: SelectFieldComponent, selector: "nc-select-field", inputs: { options: "options", selected: "selected" }, outputs: { selectedChange: "selectedChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8\">\n    <nc-dropdown [buttonText]=\"selected.title\"\n                  buttonIcon=\"marker\"\n                  [formFit]=\"true\"\n                  [disabled]=\"disabled\">\n      <li *ngFor=\"let col of options\"\n          class=\"menu-item form-check dropdown-item\"\n          (click)=\"onOptionSelect(col)\">\n        {{col.title}}\n        <div *ngIf=\"col.markerColor\"\n             class=\"dropdown-marker\"\n             style=\"background-color: {{col.markerColor}};\"></div>\n      </li>\n    </nc-dropdown>\n  </div>\n</div>\n", styles: [".dropdown-item{height:2.3835rem;padding-top:.4rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;justify-content:space-between}.dropdown-marker{display:block;width:12px;height:12px;margin-left:1rem;border-radius:50%}\n", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2$1.DropdownComponent, selector: "nc-dropdown", inputs: ["key", "buttonIcon", "buttonText", "formFit", "disabled"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SelectFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-select-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8\">\n    <nc-dropdown [buttonText]=\"selected.title\"\n                  buttonIcon=\"marker\"\n                  [formFit]=\"true\"\n                  [disabled]=\"disabled\">\n      <li *ngFor=\"let col of options\"\n          class=\"menu-item form-check dropdown-item\"\n          (click)=\"onOptionSelect(col)\">\n        {{col.title}}\n        <div *ngIf=\"col.markerColor\"\n             class=\"dropdown-marker\"\n             style=\"background-color: {{col.markerColor}};\"></div>\n      </li>\n    </nc-dropdown>\n  </div>\n</div>\n", styles: [".dropdown-item{height:2.3835rem;padding-top:.4rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;justify-content:space-between}.dropdown-marker{display:block;width:12px;height:12px;margin-left:1rem;border-radius:50%}\n", ":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }], propDecorators: { options: [{
                type: Input
            }], selected: [{
                type: Input
            }], selectedChange: [{
                type: Output
            }] } });

class TextFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.type = 'text';
        this.maxLength = -1;
        this.autocomplete = false;
        this.allowCopy = false;
    }
    afterInit() {
        if (this.maxLength > 0) {
            this.formControl.addValidators(Validators.maxLength(+this.maxLength));
        }
        setTimeout(() => {
            if (this.type === 'email') {
                this.formControl.addValidators(Validators.email);
            }
        });
    }
}
TextFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
TextFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: TextFieldComponent, selector: "nc-text-field", inputs: { type: "type", maxLength: "maxLength", autocomplete: "autocomplete", allowCopy: "allowCopy" }, usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           [type]=\"type\"\n           class=\"form-control\"\n           [class.right-padding]=\"isTrue(allowCopy)\"\n           [attr.maxlength]=\"maxLength\"\n           [autocomplete]=\"isTrue(autocomplete) ? 'on' : 'off'\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n    <button *ngIf=\"isTrue(allowCopy)\"\n            class=\"input-mark\"\n            (click)=\"copyPaste.copyToClipboard(input.value)\">\n      <i class=\"las la-copy\"></i>\n    </button>\n  </div>\n\n  <nc-field-message *ngIf=\"maxLength > 0\"\n                     size=\"small\"\n                     [text]=\"maxLength - input.value.length\"\n                     [show]=\"focused\"\n                     [warn]=\"input.value.length > maxLength * 0.8\"\n                     [error]=\"input.value.length >= maxLength\"></nc-field-message>\n\n  <nc-field-message [text]=\"errors.required\"\n                     [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n                     [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"errors.invalidEmail\"\n                     [show]=\"!focused && formControl.touched && formControl.hasError('email')\"\n                     [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                     [show]=\"formControl.hasError('api-error')\"\n                     [error]=\"true\"></nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: FieldMessageComponent, selector: "nc-field-message", inputs: ["show", "warn", "error", "text", "size"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-text-field', template: "<div class=\"row mb-3 form-grp\">\n  <label *ngIf=\"label\"\n         [for]=\"controlName\"\n         class=\"col-sm-4 col-form-label\">\n    {{label}}\n    <sup *ngIf=\"required\"\n         class=\"required-mark\">*\n    </sup>\n  </label>\n  <div class=\"col-sm-8 position-relative\">\n    <input #input\n           [formControl]=\"formControl\"\n           [id]=\"controlName\"\n           [type]=\"type\"\n           class=\"form-control\"\n           [class.right-padding]=\"isTrue(allowCopy)\"\n           [attr.maxlength]=\"maxLength\"\n           [autocomplete]=\"isTrue(autocomplete) ? 'on' : 'off'\"\n           (input)=\"onChange($event)\"\n           (focusin)=\"focused = true\"\n           (focusout)=\"focused = false\" />\n    <button *ngIf=\"isTrue(allowCopy)\"\n            class=\"input-mark\"\n            (click)=\"copyPaste.copyToClipboard(input.value)\">\n      <i class=\"las la-copy\"></i>\n    </button>\n  </div>\n\n  <nc-field-message *ngIf=\"maxLength > 0\"\n                     size=\"small\"\n                     [text]=\"maxLength - input.value.length\"\n                     [show]=\"focused\"\n                     [warn]=\"input.value.length > maxLength * 0.8\"\n                     [error]=\"input.value.length >= maxLength\"></nc-field-message>\n\n  <nc-field-message [text]=\"errors.required\"\n                     [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n                     [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"errors.invalidEmail\"\n                     [show]=\"!focused && formControl.touched && formControl.hasError('email')\"\n                     [error]=\"true\"></nc-field-message>\n\n  <nc-field-message [text]=\"formControl.getError('api-error')\"\n                     [show]=\"formControl.hasError('api-error')\"\n                     [error]=\"true\"></nc-field-message>\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n"] }]
        }], propDecorators: { type: [{
                type: Input
            }], maxLength: [{
                type: Input
            }], autocomplete: [{
                type: Input
            }], allowCopy: [{
                type: Input
            }] } });

class InputBaseComponent {
    constructor(formGroup) {
        this.formGroup = formGroup;
        this.required = false;
        this.errors = errorMessages;
        this.changed = false;
        this.focused = false;
    }
    ngOnInit() {
        this.formControl = this.formGroup.form.get(this.controlName);
        setTimeout(() => {
            if (this.required) {
                this.formControl.addValidators(Validators.required);
            }
            this.afterInit();
        });
    }
    onChange(event) {
        this.changed = true;
    }
    afterInit() { }
}
InputBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: InputBaseComponent, deps: [{ token: i2.FormGroupDirective }], target: i0.ɵɵFactoryTarget.Component });
InputBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: InputBaseComponent, selector: "input-base", inputs: { controlName: "controlName", required: "required" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: InputBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'input-base',
                    template: ``,
                }]
        }], ctorParameters: function () { return [{ type: i2.FormGroupDirective }]; }, propDecorators: { controlName: [{
                type: Input
            }], required: [{
                type: Input
            }] } });

class TextAreaInputComponent extends InputBaseComponent {
    constructor(form) {
        super(form);
        this.size = 'medium';
        this.maxLength = -1;
    }
    get value() {
        return this.input.nativeElement ? this.input.nativeElement.value : null;
    }
    set value(value) {
        this.input.nativeElement.value = value;
    }
}
TextAreaInputComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextAreaInputComponent, deps: [{ token: i2.FormGroupDirective }], target: i0.ɵɵFactoryTarget.Component });
TextAreaInputComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: TextAreaInputComponent, selector: "nc-text-area-input", inputs: { size: "size", maxLength: "maxLength" }, viewQueries: [{ propertyName: "input", first: true, predicate: ["input"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
    <textarea
      #input
      [formControl]="formControl"
      [id]="controlName"
      class="form-control {{ size }}"
      [attr.maxlength]="maxLength"
      (input)="onChange($event)"
      (focusin)="focused = true"
      (focusout)="focused = false"></textarea>
  `, isInline: true, styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "textarea.small{min-height:2.2rem;height:2.45rem;max-height:5.3rem}textarea.large{min-height:8.25rem;height:17.25rem;max-height:32.25rem}\n"], dependencies: [{ kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextAreaInputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-text-area-input', template: `
    <textarea
      #input
      [formControl]="formControl"
      [id]="controlName"
      class="form-control {{ size }}"
      [attr.maxlength]="maxLength"
      (input)="onChange($event)"
      (focusin)="focused = true"
      (focusout)="focused = false"></textarea>
  `, styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "textarea.small{min-height:2.2rem;height:2.45rem;max-height:5.3rem}textarea.large{min-height:8.25rem;height:17.25rem;max-height:32.25rem}\n"] }]
        }], ctorParameters: function () { return [{ type: i2.FormGroupDirective }]; }, propDecorators: { input: [{
                type: ViewChild,
                args: ['input']
            }], size: [{
                type: Input
            }], maxLength: [{
                type: Input
            }] } });

class TextAreaFieldComponent extends FieldBaseComponent {
    constructor() {
        super(...arguments);
        this.size = 'medium';
        this.maxLength = -1;
    }
}
TextAreaFieldComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextAreaFieldComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
TextAreaFieldComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: TextAreaFieldComponent, selector: "nc-text-area-field", inputs: { size: "size", maxLength: "maxLength" }, usesInheritance: true, ngImport: i0, template: "<div class=\"row mb-3 form-grp\">\n  <label [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\"> *</sup>\n  </label>\n  <div class=\"col-sm-8\">\n    <nc-text-area-input\n      #input\n      [controlName]=\"controlName\"\n      [size]=\"size\"\n      [maxLength]=\"maxLength\">\n    </nc-text-area-input>\n  </div>\n\n  <nc-field-message\n    *ngIf=\"maxLength > 0\"\n    size=\"small\"\n    [text]=\"maxLength - input.value.length\"\n    [show]=\"focused\"\n    [warn]=\"input.value.length > maxLength * .8\"\n    [error]=\"input.value.length >= maxLength\">\n  </nc-field-message>\n\n  <nc-field-message\n    [text]=\"errors.required\"\n    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n    [error]=\"true\">\n  </nc-field-message>\n\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "textarea.small{min-height:2.2rem;height:2.45rem;max-height:5.3rem}textarea.large{min-height:8.25rem;height:17.25rem;max-height:32.25rem}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: FieldMessageComponent, selector: "nc-field-message", inputs: ["show", "warn", "error", "text", "size"] }, { kind: "component", type: TextAreaInputComponent, selector: "nc-text-area-input", inputs: ["size", "maxLength"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TextAreaFieldComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-text-area-field', template: "<div class=\"row mb-3 form-grp\">\n  <label [for]=\"controlName\" class=\"col-sm-4 col-form-label\">\n    {{label}}<sup *ngIf=\"required\" class=\"required-mark\"> *</sup>\n  </label>\n  <div class=\"col-sm-8\">\n    <nc-text-area-input\n      #input\n      [controlName]=\"controlName\"\n      [size]=\"size\"\n      [maxLength]=\"maxLength\">\n    </nc-text-area-input>\n  </div>\n\n  <nc-field-message\n    *ngIf=\"maxLength > 0\"\n    size=\"small\"\n    [text]=\"maxLength - input.value.length\"\n    [show]=\"focused\"\n    [warn]=\"input.value.length > maxLength * .8\"\n    [error]=\"input.value.length >= maxLength\">\n  </nc-field-message>\n\n  <nc-field-message\n    [text]=\"errors.required\"\n    [show]=\"!focused && formControl.touched && formControl.hasError('required')\"\n    [error]=\"true\">\n  </nc-field-message>\n\n</div>\n", styles: [":host{display:block}.form-grp{position:relative}label{text-align:right;overflow:hidden;white-space:nowrap}.required-mark{font-size:.75rem;color:var(--danger);padding-left:.15rem}input,textarea,.dropdown-button{color:var(--input-color);background-color:var(--input-bg)}input[disabled],textarea[disabled],.dropdown-button[disabled]{cursor:text}.input-wrapper{position:relative}.input-mark{position:absolute;top:.45rem;right:1.1rem;width:1.5rem;height:1.5rem;padding:.075rem 0 0;border:none;border-radius:50%;color:var(--text);background-color:var(--gray-500)}.input-mark:hover{background-color:var(--gray-600)}.input-mark:focus,.input-mark:active{background-color:var(--primary-alt)}.right-padding{padding-right:2rem}.col-form-label{max-width:180px}.link-input{text-decoration:underline;font-weight:bolder}\n", "textarea.small{min-height:2.2rem;height:2.45rem;max-height:5.3rem}textarea.large{min-height:8.25rem;height:17.25rem;max-height:32.25rem}\n"] }]
        }], propDecorators: { size: [{
                type: Input
            }], maxLength: [{
                type: Input
            }] } });

class FormComponentsModule {
}
FormComponentsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormComponentsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
FormComponentsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.3.0", ngImport: i0, type: FormComponentsModule, declarations: [FormComponent,
        FormContentComponent,
        FieldsetComponent,
        NotFoundComponent,
        FieldMessageComponent,
        DatePickerComponent,
        DateRangePickerComponent,
        DateFieldComponent,
        TextFieldComponent,
        PasswordFieldComponent,
        TextAreaInputComponent,
        TextAreaFieldComponent,
        NumberFieldComponent,
        SelectFieldComponent,
        CheckboxFieldComponent,
        LinkFieldComponent,
        ActionFieldComponent], imports: [CommonModule, i3.NgxMaskModule, ReactiveFormsModule,
        FormsModule,
        CoreComponentsModule,
        RouterLinkWithHref], exports: [FormComponent,
        FieldsetComponent,
        FormContentComponent,
        DateFieldComponent,
        DatePickerComponent,
        TextFieldComponent,
        PasswordFieldComponent,
        TextAreaInputComponent,
        TextAreaFieldComponent,
        NumberFieldComponent,
        SelectFieldComponent,
        CheckboxFieldComponent,
        LinkFieldComponent,
        ActionFieldComponent] });
FormComponentsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormComponentsModule, imports: [CommonModule,
        NgxMaskModule.forRoot({
            validation: false,
        }),
        ReactiveFormsModule,
        FormsModule,
        CoreComponentsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: FormComponentsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        FormComponent,
                        FormContentComponent,
                        FieldsetComponent,
                        NotFoundComponent,
                        FieldMessageComponent,
                        DatePickerComponent,
                        DateRangePickerComponent,
                        DateFieldComponent,
                        TextFieldComponent,
                        PasswordFieldComponent,
                        TextAreaInputComponent,
                        TextAreaFieldComponent,
                        NumberFieldComponent,
                        SelectFieldComponent,
                        CheckboxFieldComponent,
                        LinkFieldComponent,
                        ActionFieldComponent,
                    ],
                    exports: [
                        FormComponent,
                        FieldsetComponent,
                        FormContentComponent,
                        DateFieldComponent,
                        DatePickerComponent,
                        TextFieldComponent,
                        PasswordFieldComponent,
                        TextAreaInputComponent,
                        TextAreaFieldComponent,
                        NumberFieldComponent,
                        SelectFieldComponent,
                        CheckboxFieldComponent,
                        LinkFieldComponent,
                        ActionFieldComponent,
                    ],
                    imports: [
                        CommonModule,
                        NgxMaskModule.forRoot({
                            validation: false,
                        }),
                        ReactiveFormsModule,
                        FormsModule,
                        CoreComponentsModule,
                        RouterLinkWithHref,
                    ],
                }]
        }] });

class FormServiceBase {
    constructor(controls) {
        this.router = inject(Router);
        this.modals = inject(ModalsService);
        this.toaster = inject(ToasterService);
        this.formBuilder = inject(FormBuilder);
        this.readyWrap = new FormReadyWrapper();
        this.router.routeReuseStrategy.shouldReuseRoute = () => false;
        this.form = this.formBuilder.group(controls);
    }
    init(isCreating = true) {
        if (isCreating) {
            this.setReady('ready');
        }
    }
    get ready() {
        if (!this.readyWrap) {
            throw new Error('Form ready contains an invalid value');
        }
        return this.readyWrap;
    }
    get isReady() {
        return this.readyWrap.valueOf();
    }
    get isLoading() {
        return this.readyWrap.state === 'loading';
    }
    setReady(value) {
        this.readyWrap.state = value;
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { ActionFieldComponent, CheckboxFieldComponent, DateFieldComponent, DatePickerComponent, DateRangePickerComponent, FieldBaseComponent, FieldMessageComponent, FieldsetComponent, FormComponent, FormComponentsModule, FormContentComponent, FormServiceBase, InputBaseComponent, LinkFieldComponent, NotFoundComponent, NumberFieldComponent, PasswordFieldComponent, SelectFieldComponent, TextAreaFieldComponent, TextAreaInputComponent, TextFieldComponent, errorMessages };
//# sourceMappingURL=neercms-form.mjs.map
