import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import * as i1 from 'neercms/services/viewport';

// https://stackoverflow.com/questions/400212/how-do-i-copy-to-the-clipboard-in-javascript
class CopyPasteService {
    constructor(toaster) {
        this.toaster = toaster;
    }
    copyToClipboard(text) {
        if (navigator.clipboard) {
            navigator.clipboard
                .writeText(text)
                .then(() => this.showSuccessToast())
                .catch(() => this.showFailToast());
        }
        else {
            this.fallbackCopyTextToClipboard(text);
        }
    }
    showFailToast() {
        this.toaster.showFail('Something went wrong while copying text', 'copy');
    }
    showSuccessToast() {
        this.toaster.showInfo('Text copied to your clipboard', 'copy');
    }
    fallbackCopyTextToClipboard(text) {
        const textArea = document.createElement('textarea');
        textArea.value = text;
        // Avoid scrolling to bottom
        textArea.style.top = '0';
        textArea.style.left = '0';
        textArea.style.position = 'fixed';
        document.body.appendChild(textArea);
        textArea.focus();
        textArea.select();
        let successful = false;
        try {
            successful = document.execCommand('copy');
            // console.log('Fallback: Copying text command was ' + msg);
        }
        catch (err) {
            console.error('Fallback: Oops, unable to copy', err);
        }
        document.body.removeChild(textArea);
        successful ? this.showSuccessToast() : this.showFailToast();
    }
}
CopyPasteService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: CopyPasteService, deps: [{ token: i1.ToasterService }], target: i0.ɵɵFactoryTarget.Injectable });
CopyPasteService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: CopyPasteService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: CopyPasteService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: function () { return [{ type: i1.ToasterService }]; } });

class NumberInputProcessorService {
    patternToMask(pattern) {
        if (pattern === undefined || pattern === 'integer') {
            return 'separator.0';
        }
        else if (pattern === 'float') {
            return 'separator.12';
        }
        else if (pattern.startsWith('float')) {
            const accuracy = pattern.replace(/(^.*\(|\).*$)/g, '');
            return 'separator.' + accuracy;
        }
        else {
            return pattern;
        }
    }
    clampValue(formControl, minValue, maxValue) {
        const value = +formControl.value;
        if (minValue && value < minValue) {
            formControl.setValue(minValue);
        }
        else if (maxValue && value > maxValue) {
            formControl.setValue(maxValue);
        }
    }
    onKeyUp(formControl, minValue, maxValue, event) {
        // To avoid a float numbers math hell
        function fuckJS(n, inc) {
            const [integer, floating] = n.toString().split('.');
            return parseFloat(+integer + inc + '.' + floating);
        }
        if (formControl.value === null || formControl.value === undefined) {
            return;
        }
        if (formControl.value === 0 && +event.key) {
            formControl.setValue(+event.key);
        }
        else if (event.key === 'ArrowUp') {
            formControl.setValue(fuckJS(formControl.value, 1));
            this.clampValue(formControl, minValue, maxValue);
        }
        else if (event.key === 'ArrowDown') {
            formControl.setValue(fuckJS(formControl.value, -1));
            this.clampValue(formControl, minValue, maxValue);
        }
    }
}
NumberInputProcessorService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NumberInputProcessorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
NumberInputProcessorService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NumberInputProcessorService, providedIn: 'any' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: NumberInputProcessorService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'any' }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CopyPasteService, NumberInputProcessorService };
//# sourceMappingURL=neercms-services.mjs.map
