import * as i0 from '@angular/core';
import { Directive, EventEmitter, inject, Component, ContentChild, Input, Output, NgModule } from '@angular/core';
import { NeerStorageService } from 'neercms/services/storage';
import { ViewportService } from 'neercms/services/viewport';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'angular-split';
import { AngularSplitModule } from 'angular-split';

class SplitOneDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
SplitOneDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitOneDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
SplitOneDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.3.0", type: SplitOneDirective, selector: "[ncSplitOne]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitOneDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ncSplitOne]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });

class SplitTwoDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
SplitTwoDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitTwoDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
SplitTwoDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.3.0", type: SplitTwoDirective, selector: "[ncSplitTwo]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitTwoDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ncSplitTwo]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });

class SplitComponent {
    constructor() {
        this.sizes = [100, 0];
        this.defaultSizes = [100, 0];
        this.splitSizesChange = new EventEmitter();
        this.storage = inject(NeerStorageService);
        this.device = inject(ViewportService);
    }
    ngOnInit() {
        if (!this.storageKey) {
            throw new Error("Property 'storageKey' is required!");
        }
        this.setSizes(this.storage.getSplitSizes(this.storageKey));
    }
    resize(newSizes) {
        const firstSize = newSizes[0];
        const secondSize = newSizes[1];
        if (firstSize < 20 && firstSize < this.sizes[0]) {
            this.setSizes([0, 100]);
        }
        else if (secondSize < 20 && secondSize < this.sizes[1]) {
            this.setSizes([100, 0]);
        }
        else if (Math.abs(firstSize - secondSize) < 10) {
            this.setSizes([50, 50]);
        }
        else {
            this.setSizes([firstSize, secondSize]);
        }
        this.storage.setSplitSizes(this.storageKey, this.sizes);
        return this.sizes;
    }
    maximizeAreaOne() {
        if (this.device.isTablet) {
            this.sizes = this.resize([100, 0]);
        }
        else {
            this.sizes = this.resize([50, 50]);
        }
    }
    maximizeAreaTwo() {
        if (this.device.isTablet) {
            this.sizes = this.resize([0, 100]);
        }
        else {
            this.sizes = this.resize([50, 50]);
        }
    }
    closeForm() {
        this.sizes = this.resize([100, 0]);
    }
    setSizes(sizes) {
        if (!sizes || sizes.length !== 2) {
            sizes = this.defaultSizes;
        }
        this.sizes = sizes;
        this.splitSizesChange.emit(sizes);
    }
}
SplitComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SplitComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: SplitComponent, selector: "nc-split", inputs: { storageKey: "storageKey", sizes: "sizes", defaultSizes: "defaultSizes" }, outputs: { splitSizesChange: "splitSizesChange" }, queries: [{ propertyName: "splitAreaOne", first: true, predicate: SplitOneDirective, descendants: true }, { propertyName: "splitAreaTwo", first: true, predicate: SplitTwoDirective, descendants: true }], ngImport: i0, template: "<as-split class=\"split-view\"\n          unit=\"percent\"\n          direction=\"vertical\"\n          [gutterSize]=\"4\"\n          (dragEnd)=\"resize($event.sizes)\">\n  <as-split-area [size]=\"sizes[0]\">\n    <div class=\"split-area-content\">\n      <ng-container [ngTemplateOutlet]=\"splitAreaOne.templateRef\"></ng-container>\n    </div>\n  </as-split-area>\n  <as-split-area [size]=\"sizes[1]\">\n    <div class=\"split-area-content\">\n      <ng-container [ngTemplateOutlet]=\"splitAreaTwo.templateRef\"></ng-container>\n    </div>\n  </as-split-area>\n</as-split>\n", styles: [":host{display:block;height:100%}.split-view{width:100%;height:100%}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.SplitComponent, selector: "as-split", inputs: ["direction", "unit", "gutterSize", "gutterStep", "restrictMove", "useTransition", "disabled", "dir", "gutterDblClickDuration", "gutterClickDeltaPx", "gutterAriaLabel"], outputs: ["transitionEnd", "dragStart", "dragEnd", "gutterClick", "gutterDblClick"], exportAs: ["asSplit"] }, { kind: "directive", type: i2.SplitAreaDirective, selector: "as-split-area, [as-split-area]", inputs: ["order", "size", "minSize", "maxSize", "lockSize", "visible"], exportAs: ["asSplitArea"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-split', template: "<as-split class=\"split-view\"\n          unit=\"percent\"\n          direction=\"vertical\"\n          [gutterSize]=\"4\"\n          (dragEnd)=\"resize($event.sizes)\">\n  <as-split-area [size]=\"sizes[0]\">\n    <div class=\"split-area-content\">\n      <ng-container [ngTemplateOutlet]=\"splitAreaOne.templateRef\"></ng-container>\n    </div>\n  </as-split-area>\n  <as-split-area [size]=\"sizes[1]\">\n    <div class=\"split-area-content\">\n      <ng-container [ngTemplateOutlet]=\"splitAreaTwo.templateRef\"></ng-container>\n    </div>\n  </as-split-area>\n</as-split>\n", styles: [":host{display:block;height:100%}.split-view{width:100%;height:100%}\n"] }]
        }], propDecorators: { splitAreaOne: [{
                type: ContentChild,
                args: [SplitOneDirective]
            }], splitAreaTwo: [{
                type: ContentChild,
                args: [SplitTwoDirective]
            }], storageKey: [{
                type: Input
            }], sizes: [{
                type: Input
            }], defaultSizes: [{
                type: Input
            }], splitSizesChange: [{
                type: Output
            }] } });

class SplitComponentsModule {
}
SplitComponentsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitComponentsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SplitComponentsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.3.0", ngImport: i0, type: SplitComponentsModule, declarations: [SplitComponent, SplitOneDirective, SplitTwoDirective], imports: [CommonModule, AngularSplitModule], exports: [SplitComponent, SplitOneDirective, SplitTwoDirective] });
SplitComponentsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitComponentsModule, imports: [CommonModule, AngularSplitModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: SplitComponentsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SplitComponent, SplitOneDirective, SplitTwoDirective],
                    imports: [CommonModule, AngularSplitModule],
                    exports: [SplitComponent, SplitOneDirective, SplitTwoDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SplitComponent, SplitComponentsModule, SplitOneDirective, SplitTwoDirective };
//# sourceMappingURL=neercms-split.mjs.map
