import * as i0 from '@angular/core';
import { Component, Input, Directive, QueryList, ViewContainerRef, ContentChildren, ViewChild, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { DataTableError } from 'neercms/table/types';

class TabContext {
    constructor(key, tabRef, tabs) {
        this.key = key;
        this.tabRef = tabRef;
        this.tabs = tabs;
    }
    rename(newTitle) {
        this.tabRef.title = newTitle;
    }
    select() {
        this.tabs.selectTab(this.tabRef);
    }
    close() {
        this.tabs.closeTab(this.tabRef);
    }
}

class TabComponent {
    constructor() {
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.title = 'title';
        this.active = false;
        this.isCloseable = false;
    }
    ngOnInit() {
        this.context = new TabContext(this.key, this, this.tabs);
    }
}
TabComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TabComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: TabComponent, selector: "nc-tab", inputs: { title: ["tabTitle", "title"], active: "active", isCloseable: "isCloseable", key: "key", template: "template", data: "data", tabs: "tabs" }, ngImport: i0, template: "<div [hidden]=\"!active\"\n     class=\"pane\">\n  <ng-content></ng-content>\n  <ng-container *ngIf=\"template\"\n                [ngTemplateOutlet]=\"template\"\n                [ngTemplateOutletContext]=\"{$implicit: data, context: context}\"></ng-container>\n</div>\n", styles: [".pane{padding:1rem 1rem 0 0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-tab', template: "<div [hidden]=\"!active\"\n     class=\"pane\">\n  <ng-content></ng-content>\n  <ng-container *ngIf=\"template\"\n                [ngTemplateOutlet]=\"template\"\n                [ngTemplateOutletContext]=\"{$implicit: data, context: context}\"></ng-container>\n</div>\n", styles: [".pane{padding:1rem 1rem 0 0}\n"] }]
        }], propDecorators: { title: [{
                type: Input,
                args: ['tabTitle']
            }], active: [{
                type: Input
            }], isCloseable: [{
                type: Input
            }], key: [{
                type: Input
            }], template: [{
                type: Input
            }], data: [{
                type: Input
            }], tabs: [{
                type: Input
            }] } });

class TabTemplateContext {
}
class TabTemplateDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    set ncTabTemplate(templateName) {
        if (!templateName) {
            throw new DataTableError("ncTabTemplate' name must be specified!");
        }
        this.templateName = templateName;
    }
}
TabTemplateDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabTemplateDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
TabTemplateDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.3.0", type: TabTemplateDirective, selector: "[ncTabTemplate]", inputs: { ncTabTemplate: "ncTabTemplate" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ncTabTemplate]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; }, propDecorators: { ncTabTemplate: [{
                type: Input
            }] } });

class TabsComponent {
    constructor() {
        this.templates = new QueryList();
        this.tabs = new QueryList();
        this.dynamicTabs = [];
        this.openedTabKeys = [];
    }
    ngAfterContentInit() {
        let activeTabs = this.tabs.filter(tab => tab.active);
        if (activeTabs.length === 0 && this.tabs.first) {
            this.selectTab(this.tabs.first);
        }
        for (const tab of this.tabs) {
            if (tab.key && !this.openedTabKeys.includes(tab.key)) {
                this.openedTabKeys.push(tab.key);
            }
        }
    }
    selectTab(tab) {
        this.tabs.toArray().forEach(tab => (tab.active = false));
        this.dynamicTabs.forEach(tab => (tab.active = false));
        tab.active = true;
    }
    openDefaultTab(key, title, data, isCloseable = true) {
        const defaultTemplate = this.templates.get(0);
        if (!defaultTemplate) {
            throw new Error('No templates found.');
        }
        this.openTab(key, title, defaultTemplate.templateName, data, isCloseable);
    }
    openTab(key, title, templateName, data, isCloseable = true) {
        if (this.openedTabKeys.includes(key)) {
            let tab = this.tabs.find(x => x.key === key) ?? this.dynamicTabs.find(x => x.key === key);
            if (tab) {
                this.selectTab(tab);
                return;
            }
        }
        const tabType = TabComponent;
        const componentRef = this.dynamicTabsContainer.createComponent(tabType);
        const instance = componentRef.instance;
        instance.title = title;
        instance.key = key;
        instance.template = this.templates.find(x => x.templateName === templateName).templateRef;
        instance.data = data;
        instance.isCloseable = isCloseable;
        instance.active = true;
        instance.tabs = this;
        this.dynamicTabs.push(componentRef.instance);
        this.openedTabKeys.push(key);
        this.selectTab(componentRef.instance);
    }
    closeTab(tab) {
        for (let i = 0; i < this.dynamicTabs.length; i++) {
            if (this.dynamicTabs[i] === tab) {
                this.dynamicTabs.splice(i, 1);
                this.dynamicTabsContainer.remove(i);
                this.openedTabKeys = this.openedTabKeys.filter(x => x !== tab.key);
                if (this.tabs.first) {
                    this.selectTab(this.tabs.first);
                }
                else if (this.dynamicTabs.length > 0) {
                    this.selectTab(this.dynamicTabs[0]);
                }
                break;
            }
        }
    }
    closeAllTabs() {
        this.dynamicTabs = [];
        this.dynamicTabsContainer.clear();
    }
}
TabsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TabsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.3.0", type: TabsComponent, selector: "nc-tabs", queries: [{ propertyName: "templates", predicate: TabTemplateDirective }, { propertyName: "tabs", predicate: TabComponent }], viewQueries: [{ propertyName: "dynamicTabsContainer", first: true, predicate: ["container"], descendants: true, read: ViewContainerRef }], ngImport: i0, template: "<ul class=\"nav nav-tabs\">\n  <li *ngFor=\"let tab of tabs\"\n      (click)=\"selectTab(tab)\"\n      [class.active]=\"tab.active\"\n      class=\"tab\">\n    <button class=\"btn btn-outline-secondary\">{{tab.title}}</button>\n  </li>\n  <!-- dynamic tabs -->\n  <li *ngFor=\"let tab of dynamicTabs\"\n      (click)=\"selectTab(tab)\"\n      [class.active]=\"tab.active\"\n      class=\"tab\">\n    <button class=\"btn btn-outline-secondary\">{{tab.title}}\n      <i *ngIf=\"tab.isCloseable\"\n         (click)=\"closeTab(tab)\"\n         class=\"las la-times\"></i>\n    </button>\n  </li>\n</ul>\n<ng-template #container></ng-template>\n", styles: [".nav-tabs{display:flex;gap:2px;align-items:flex-end;padding-top:7px}.tab button{background-color:var(--tabs-inactive-bg);padding:.4rem .5rem .4rem 1rem;margin-top:.6rem;color:var(--tabs-inactive-color);border-width:0;transition:padding .1s ease,margin .1s ease}.tab i{margin-left:.25rem}.tab-close{color:var(--text);text-align:right;cursor:pointer}li.active button{background-color:var(--tabs-active-bg);color:var(--tabs-active-color);padding-top:.6rem;padding-bottom:.8rem;margin-top:0;transition:padding .1s ease,margin .1s ease}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'nc-tabs', template: "<ul class=\"nav nav-tabs\">\n  <li *ngFor=\"let tab of tabs\"\n      (click)=\"selectTab(tab)\"\n      [class.active]=\"tab.active\"\n      class=\"tab\">\n    <button class=\"btn btn-outline-secondary\">{{tab.title}}</button>\n  </li>\n  <!-- dynamic tabs -->\n  <li *ngFor=\"let tab of dynamicTabs\"\n      (click)=\"selectTab(tab)\"\n      [class.active]=\"tab.active\"\n      class=\"tab\">\n    <button class=\"btn btn-outline-secondary\">{{tab.title}}\n      <i *ngIf=\"tab.isCloseable\"\n         (click)=\"closeTab(tab)\"\n         class=\"las la-times\"></i>\n    </button>\n  </li>\n</ul>\n<ng-template #container></ng-template>\n", styles: [".nav-tabs{display:flex;gap:2px;align-items:flex-end;padding-top:7px}.tab button{background-color:var(--tabs-inactive-bg);padding:.4rem .5rem .4rem 1rem;margin-top:.6rem;color:var(--tabs-inactive-color);border-width:0;transition:padding .1s ease,margin .1s ease}.tab i{margin-left:.25rem}.tab-close{color:var(--text);text-align:right;cursor:pointer}li.active button{background-color:var(--tabs-active-bg);color:var(--tabs-active-color);padding-top:.6rem;padding-bottom:.8rem;margin-top:0;transition:padding .1s ease,margin .1s ease}\n"] }]
        }], propDecorators: { templates: [{
                type: ContentChildren,
                args: [TabTemplateDirective]
            }], tabs: [{
                type: ContentChildren,
                args: [TabComponent]
            }], dynamicTabsContainer: [{
                type: ViewChild,
                args: ['container', { read: ViewContainerRef }]
            }] } });

class TabComponentsModule {
}
TabComponentsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabComponentsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TabComponentsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.3.0", ngImport: i0, type: TabComponentsModule, declarations: [TabTemplateDirective, TabComponent, TabsComponent], imports: [CommonModule], exports: [TabTemplateDirective, TabComponent, TabsComponent] });
TabComponentsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabComponentsModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: TabComponentsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TabTemplateDirective, TabComponent, TabsComponent],
                    imports: [CommonModule],
                    exports: [TabTemplateDirective, TabComponent, TabsComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TabComponent, TabComponentsModule, TabContext, TabTemplateDirective, TabsComponent };
//# sourceMappingURL=neercms-tabs.mjs.map
